﻿using Android.App;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using Android.Graphics;
using Android.Views;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System;

namespace ChartSample
{
    [Activity(Label = "ChartSample", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        public ObservableCollection<ChartDataPoint> HighTemperature1;

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            SfChart chart = new SfChart(this);
            chart.Title.Text = "Weather Analysis";
            chart.SetBackgroundColor(Color.White);

            HighTemperature1 = new ObservableCollection<ChartDataPoint>();
            HighTemperature1.Add(new ChartDataPoint(0.2, 42));
            HighTemperature1.Add(new ChartDataPoint(0.8, 48.05));
            HighTemperature1.Add(new ChartDataPoint(1.3, 64.76));
            HighTemperature1.Add(new ChartDataPoint(1.7, 44.05));
            HighTemperature1.Add(new ChartDataPoint(2.1, 64.76));
            HighTemperature1.Add(new ChartDataPoint(2.5, 25.10));

         
            NumericalAxis primaryAxis = new NumericalAxis();
            primaryAxis.Title.Text = "Days";
            chart.PrimaryAxis = primaryAxis;

            NumericalAxis secondaryAxis = new NumericalAxis();
            secondaryAxis.Title.Text = "Temperature";
            chart.SecondaryAxis = secondaryAxis;

            chart.Series.Add(new LineSeries()
            {
                ItemsSource = HighTemperature1,
                XBindingPath = "XValue",
                YBindingPath = "YValue"
            });

            chart.Behaviors.Add(new CustomTrackballBehavior());

            SetContentView(chart);
        }
    }

    public class CustomTrackballBehavior : ChartTrackballBehavior
    {
        public CustomTrackballBehavior()
        {
            LabelDisplayMode = TrackballLabelDisplayMode.FloatAllPoints;

        }
        protected override View GetView(ChartSeries series, object data, int index)
        {
     
            //View vv = LayoutInflater.From(Application.Context).Inflate(Resource.Layout.layout1, null);
            LinearLayout rootLayout = new LinearLayout(Chart.Context);
            rootLayout.Orientation = Orientation.Vertical;
            
           // rootLayout.Gravity = GravityFlags.Top;
            rootLayout.SetGravity(GravityFlags.Top);

            TextView xValue = new TextView(Chart.Context);
            xValue.Text = "XValue : " + (data as ChartDataPoint).GetX().ToString();
            xValue.SetTextColor(Color.White);
            xValue.TextSize = 10;

            TextView yValue = new TextView(Chart.Context);
            yValue.Text = "YValue : " + (data as ChartDataPoint).GetY().ToString();
            yValue.SetTextColor(Color.White);
            yValue.TextSize = 10;

            rootLayout.AddView(xValue);
            rootLayout.AddView(yValue);

            return rootLayout;
        }
        protected override void DrawLabel(Canvas canvas, ChartPointInfo pointInfo, RectF rect)
        {
            float  newTop = 10 + 20;
            float newButtom = newTop + Math.Abs(rect.Top - rect.Bottom) + 50;

            rect.Top = newTop;
            rect.Bottom = newButtom;

            base.DrawLabel(canvas, pointInfo, rect);
        }
        protected override View GetAxisView(string p0, ChartAxis p1)
        {
            return base.GetAxisView(p0, p1);
        }
        protected override void DrawLine(Canvas canvas, float x1, float x2, float y1, float y2)
        {
            base.DrawLine(canvas, x1, x2, y1, y2);
        }
        protected override View GetView(ChartSeries p0, ChartDataPoint p1, int p2)
        {
            return base.GetView(p0, p1, p2);
        }

        protected override void OnTouchDown(float x, float y)
        {
            Show(x, y);
        }
    }
}

